summaryrefslogtreecommitdiffstats
path: root/kspread/valueparser.cc
diff options
context:
space:
mode:
Diffstat (limited to 'kspread/valueparser.cc')
-rw-r--r--kspread/valueparser.cc10
1 files changed, 5 insertions, 5 deletions
diff --git a/kspread/valueparser.cc b/kspread/valueparser.cc
index ff5b4b8c..08ebe628 100644
--- a/kspread/valueparser.cc
+++ b/kspread/valueparser.cc
@@ -27,11 +27,11 @@
using namespace KSpread;
-ValueParser::ValueParser( KLocale* locale ) : parserLocale( locale )
+ValueParser::ValueParser( TDELocale* locale ) : parserLocale( locale )
{
}
-KLocale* ValueParser::locale()
+TDELocale* ValueParser::locale()
{
return parserLocale;
}
@@ -364,7 +364,7 @@ Value ValueParser::tryParseDate (const TQString& str, bool *ok)
{
// Note: if shortdate format only specifies 2 digits year, then 3/4/1955
// will be treated as in year 3055, while 3/4/55 as year 2055
// (because 55 < 69, see KLocale) and thus there's no way to enter for
// year 1995
// The following fixes the problem, 3/4/1955 will always be 1955
@@ -374,11 +374,11 @@ Value ValueParser::tryParseDate (const TQString& str, bool *ok)
tmpDate = tmpDate.addYears( -1900 );
// this is another HACK !
// with two digit years, 0-69 is treated as year 2000-2069 (see KLocale)
// however, in Excel only 0-29 is year 2000-2029, 30 or later is 1930
// onwards
// the following provides workaround for KLocale so we're compatible
// with Excel
// (e.g 3/4/45 is Mar 4, 1945 not Mar 4, 2045)
if( ( tmpDate.year() >= 2030 ) && ( tmpDate.year() <= 2069 ) )
@@ -364,7 +364,7 @@ Value ValueParser::tryParseDate (const TQString& str, bool *ok)
// Note: if shortdate format only specifies 2 digits year, then 3/4/1955
// will be treated as in year 3055, while 3/4/55 as year 2055
- // (because 55 < 69, see KLocale) and thus there's no way to enter for
+ // (because 55 < 69, see TDELocale) and thus there's no way to enter for
// year 1995
// The following fixes the problem, 3/4/1955 will always be 1955
@@ -374,11 +374,11 @@ Value ValueParser::tryParseDate (const TQString& str, bool *ok)
tmpDate = tmpDate.addYears( -1900 );
// this is another HACK !
- // with two digit years, 0-69 is treated as year 2000-2069 (see KLocale)
+ // with two digit years, 0-69 is treated as year 2000-2069 (see TDELocale)
// however, in Excel only 0-29 is year 2000-2029, 30 or later is 1930
// onwards
@@ -374,11 +374,11 @@ Value ValueParser::tryParseDate (const TQString& str, bool *ok)
// however, in Excel only 0-29 is year 2000-2029, 30 or later is 1930
// onwards
- // the following provides workaround for KLocale so we're compatible
+ // the following provides workaround for TDELocale so we're compatible
// with Excel
// (e.g 3/4/45 is Mar 4, 1945 not Mar 4, 2045)